.. _webassets: https://github.com/miracle2k/webassets
.. _Jinja2: http://jinja.pocoo.org/
.. _Babel: https://pypi.python.org/pypi/Babel

Introduction
============

Optimus is a static site builder. It produces HTML from templates (through `Jinja2`_) with assets management (through `webassets`_) and i18n support for translations (through `Babel`_).

Read the Optimus documentation on `<https://optimus.readthedocs.org/>`_

Links
*****

* Read the documentation on `Read the docs <https://optimus.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/Optimus>`_;
* Clone it on its `Github repository <https://github.com/sveetch/Optimus>`_;
